@@ -1,9 +1,6 @@
 """pypyr dynamic modules, namespaces and path discovery.
 
 Load modules dynamically, find things on file-system.
-
-Attributes:
-    CWD (Path): Global shared current working dir.
 """
 import ast
 import builtins
@@ -16,13 +13,11 @@ from threading import Lock
 
 from pypyr.errors import PyModuleNotFoundError
 
-CWD = Path.cwd()
-
-# use pypyr logger to ensure loglevel is set correctly
 logger = logging.getLogger(__name__)
 
 
-class _ChainMapPretendDict(ChainMap, dict):
+class _ChainMapPretendDict(ChainMap, dict):  # type: ignore
+    # mypy gets confused with multiple inheritance, thus ignore
     """It's a ChainMap. But it will pass an isinstance check for dict.
 
     Don't Use Me. Seriously.
