@@ -7,7 +7,7 @@ logger = logging.getLogger(__name__)
 
 
 def run_step(context):
-    """pypyr step saves current utc datetime to context.
+    """Save current utc datetime to context.
 
     Args:
         context: pypyr.context.Context. Mandatory.
@@ -31,12 +31,12 @@ def run_step(context):
     """
     logger.debug("started")
 
-    format_expression = context.get('nowUtcIn', None)
+    format_expression = context.get_formatted_value(context.get('nowUtcIn',
+                                                                None))
 
     if format_expression:
-        formatted_expression = context.get_formatted_string(format_expression)
         context['nowUtc'] = datetime.now(
-            timezone.utc).strftime(formatted_expression)
+            timezone.utc).strftime(format_expression)
     else:
         context['nowUtc'] = datetime.now(timezone.utc).isoformat()
 
